import type { PropType } from 'vue';
declare const _default: import("vue").DefineComponent<{
    /**
     * The color variant of the checkbox
     * @type light | dark
     * @default
     * @name color
     */
    color: {
        type: StringConstructor;
        default: undefined;
    };
    /**
     * The disabled state of the checkbox
     * @type Boolean
     * @default false
     * @name disabled
     */
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The error state of the checkbox, computed based on schema by default.
     * @type Boolean | Array
     * @default ['touched', 'dirty', 'invalid']
     * @TODO use propDefaultValue to set default value
     * @name error
     */
    error: {
        type: PropType<boolean | string[]>;
        default: () => string[];
    };
    /**
     * The indeterminate state of the checkbox
     * @type Boolean
     * @default false
     * @name indeterminate
     */
    indeterminate: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * [Deprecated] Used to set the checkbox value when used inside a checkbox group
     * @default false
     * @name value
     * @deprecated
     */
    value: {
        default: undefined;
    };
    /**
     * Used to set the checkbox value when used by itself
     * @default false
     * @name modelValue
     */
    modelValue: {
        default: boolean;
    };
    /**
     * The unique identifier of the checkbox
     * @type String
     * @default uid()
     * @name name
     */
    name: {
        type: StringConstructor;
        default: () => string;
    };
    /**
     * Displays the native browser checkbox input indicator
     * @type Boolean
     * @default false
     * @name native
     */
    native: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The readonly state of the checkbox
     * @type Boolean
     * @default false
     * @name readonly
     */
    readonly: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The size variant of the checkbox
     * @type sm | md | lg
     * @default
     * @name size
     *
     */
    size: {
        type: StringConstructor;
        default: undefined;
    };
    /**
     * The tabindex of the checkbox
     * @type Number | String
     * @default 0
     * @name tabindex
     */
    tabindex: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * Enable checkbox validation using schema
     * @type Boolean
     * @default true
     * @name validateSchema
     */
    validate: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The label to be displayed alongside the checkbox. Can be a string, number, render function, or component
     * @type String | Number | Boolean | Function | Object
     * @default undefined
     * @name label
     */
    label: {
        type: PropType<CheckboxGroupOption>;
        default: undefined;
    };
    /**
     * The option object of the checkbox when used inside a checkbox group
     * @type Object
     * @default undefined
     * @name option
     */
    option: {
        type: PropType<CheckboxGroupOption>;
        default: undefined;
    };
}, {
    classes: import("vue").ComputedRef<{
        [x: string]: any;
        '-disabled': any;
        '-readonly': any;
        '-native': boolean;
        '-error': any;
    }>;
    checked: import("vue").ComputedRef<any>;
    disabled: import("vue").ComputedRef<any>;
    readonly: import("vue").ComputedRef<any>;
    tabindex: import("vue").ComputedRef<string | number>;
    inputRef: import("vue").Ref<HTMLInputElement | null>;
    onChange: (event: Event) => void;
    labelOnBlur: (event: FocusEvent) => void;
    labelOnClick: (event: MouseEvent) => void;
    labelOnKeydown: (event: KeyboardEvent) => void;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, "update:modelValue"[], "update:modelValue", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * The color variant of the checkbox
     * @type light | dark
     * @default
     * @name color
     */
    color: {
        type: StringConstructor;
        default: undefined;
    };
    /**
     * The disabled state of the checkbox
     * @type Boolean
     * @default false
     * @name disabled
     */
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The error state of the checkbox, computed based on schema by default.
     * @type Boolean | Array
     * @default ['touched', 'dirty', 'invalid']
     * @TODO use propDefaultValue to set default value
     * @name error
     */
    error: {
        type: PropType<boolean | string[]>;
        default: () => string[];
    };
    /**
     * The indeterminate state of the checkbox
     * @type Boolean
     * @default false
     * @name indeterminate
     */
    indeterminate: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * [Deprecated] Used to set the checkbox value when used inside a checkbox group
     * @default false
     * @name value
     * @deprecated
     */
    value: {
        default: undefined;
    };
    /**
     * Used to set the checkbox value when used by itself
     * @default false
     * @name modelValue
     */
    modelValue: {
        default: boolean;
    };
    /**
     * The unique identifier of the checkbox
     * @type String
     * @default uid()
     * @name name
     */
    name: {
        type: StringConstructor;
        default: () => string;
    };
    /**
     * Displays the native browser checkbox input indicator
     * @type Boolean
     * @default false
     * @name native
     */
    native: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The readonly state of the checkbox
     * @type Boolean
     * @default false
     * @name readonly
     */
    readonly: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The size variant of the checkbox
     * @type sm | md | lg
     * @default
     * @name size
     *
     */
    size: {
        type: StringConstructor;
        default: undefined;
    };
    /**
     * The tabindex of the checkbox
     * @type Number | String
     * @default 0
     * @name tabindex
     */
    tabindex: {
        type: (StringConstructor | NumberConstructor)[];
        default: number;
    };
    /**
     * Enable checkbox validation using schema
     * @type Boolean
     * @default true
     * @name validateSchema
     */
    validate: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The label to be displayed alongside the checkbox. Can be a string, number, render function, or component
     * @type String | Number | Boolean | Function | Object
     * @default undefined
     * @name label
     */
    label: {
        type: PropType<CheckboxGroupOption>;
        default: undefined;
    };
    /**
     * The option object of the checkbox when used inside a checkbox group
     * @type Object
     * @default undefined
     * @name option
     */
    option: {
        type: PropType<CheckboxGroupOption>;
        default: undefined;
    };
}>> & {
    "onUpdate:modelValue"?: ((...args: any[]) => any) | undefined;
}, {
    color: string;
    size: string;
    value: undefined;
    name: string;
    label: CheckboxGroupOption;
    option: CheckboxGroupOption;
    error: boolean | string[];
    disabled: boolean;
    readonly: boolean;
    validate: boolean;
    modelValue: boolean;
    tabindex: string | number;
    indeterminate: boolean;
    native: boolean;
}, {}>;
export default _default;
