export const manifest = {
  name: "IProgress",
  props: [
    {
      name: "color",
      type: ["light", "dark"],
      default: "",
      description: "The color variant of the progress component"
    },
    {
      name: "min",
      type: ["Number"],
      default: "0",
      description: "The value to consider as the 0% starting point"
    },
    {
      name: "max",
      type: ["Number"],
      default: "100",
      description: "The value to consider as the 100% ending point"
    },
    {
      name: "size",
      type: ["sm", "md", "lg"],
      default: "",
      description: "The size variant of the progress component"
    }
  ],
  events: [],
  slots: [
    {
      name: "default",
      description: "Slot for progress bars "
    }
  ],
  css: {
    selector: ".progress",
    variables: [
      {
        name: "--progress--background",
        variants: [
          {
            name: "--progress--light--background",
            value: [
              {
                name: "--color-light"
              }
            ]
          },
          {
            name: "--progress--dark--background",
            value: [
              {
                name: "--color-dark"
              }
            ]
          }
        ]
      },
      {
        name: "--progress--border-radius",
        value: [
          {
            name: "--progress--border-top-left-radius",
            value: [
              {
                name: "--border-top-left-radius"
              }
            ],
            variants: [
              {
                name: "--progress--sm--border-top-left-radius",
                value: [
                  {
                    value: "calc(var(--border-top-left-radius) * var(--size-multiplier-sm))"
                  }
                ]
              },
              {
                name: "--progress--md--border-top-left-radius",
                value: [
                  {
                    value: "calc(var(--border-top-left-radius) * var(--size-multiplier-md))"
                  }
                ]
              },
              {
                name: "--progress--lg--border-top-left-radius",
                value: [
                  {
                    value: "calc(var(--border-top-left-radius) * var(--size-multiplier-lg))"
                  }
                ]
              }
            ]
          },
          {
            name: "--progress--border-top-right-radius",
            value: [
              {
                name: "--border-top-right-radius"
              }
            ],
            variants: [
              {
                name: "--progress--sm--border-top-right-radius",
                value: [
                  {
                    value: "calc(var(--border-top-right-radius) * var(--size-multiplier-sm))"
                  }
                ]
              },
              {
                name: "--progress--md--border-top-right-radius",
                value: [
                  {
                    value: "calc(var(--border-top-right-radius) * var(--size-multiplier-md))"
                  }
                ]
              },
              {
                name: "--progress--lg--border-top-right-radius",
                value: [
                  {
                    value: "calc(var(--border-top-right-radius) * var(--size-multiplier-lg))"
                  }
                ]
              }
            ]
          },
          {
            name: "--progress--border-bottom-right-radius",
            value: [
              {
                name: "--border-bottom-right-radius"
              }
            ],
            variants: [
              {
                name: "--progress--sm--border-bottom-right-radius",
                value: [
                  {
                    value: "calc(var(--border-bottom-right-radius) * var(--size-multiplier-sm))"
                  }
                ]
              },
              {
                name: "--progress--md--border-bottom-right-radius",
                value: [
                  {
                    value: "calc(var(--border-bottom-right-radius) * var(--size-multiplier-md))"
                  }
                ]
              },
              {
                name: "--progress--lg--border-bottom-right-radius",
                value: [
                  {
                    value: "calc(var(--border-bottom-right-radius) * var(--size-multiplier-lg))"
                  }
                ]
              }
            ]
          },
          {
            name: "--progress--border-bottom-left-radius",
            value: [
              {
                name: "--border-bottom-left-radius"
              }
            ],
            variants: [
              {
                name: "--progress--sm--border-bottom-left-radius",
                value: [
                  {
                    value: "calc(var(--border-bottom-left-radius) * var(--size-multiplier-sm))"
                  }
                ]
              },
              {
                name: "--progress--md--border-bottom-left-radius",
                value: [
                  {
                    value: "calc(var(--border-bottom-left-radius) * var(--size-multiplier-md))"
                  }
                ]
              },
              {
                name: "--progress--lg--border-bottom-left-radius",
                value: [
                  {
                    value: "calc(var(--border-bottom-left-radius) * var(--size-multiplier-lg))"
                  }
                ]
              }
            ]
          }
        ]
      },
      {
        name: "--progress--border-color",
        value: [
          {
            name: "--progress--border-top-color",
            value: [
              {
                name: "--border-top-color"
              }
            ],
            variants: [
              {
                name: "--progress--light--border-top-color",
                value: [
                  {
                    name: "--color-light-shade-50"
                  }
                ]
              },
              {
                name: "--progress--dark--border-top-color",
                value: [
                  {
                    name: "--color-dark-tint-50"
                  }
                ]
              }
            ]
          },
          {
            name: "--progress--border-right-color",
            value: [
              {
                name: "--border-right-color"
              }
            ],
            variants: [
              {
                name: "--progress--light--border-right-color",
                value: [
                  {
                    name: "--color-light-shade-50"
                  }
                ]
              },
              {
                name: "--progress--dark--border-right-color",
                value: [
                  {
                    name: "--color-dark-tint-50"
                  }
                ]
              }
            ]
          },
          {
            name: "--progress--border-bottom-color",
            value: [
              {
                name: "--border-bottom-color"
              }
            ],
            variants: [
              {
                name: "--progress--light--border-bottom-color",
                value: [
                  {
                    name: "--color-light-shade-50"
                  }
                ]
              },
              {
                name: "--progress--dark--border-bottom-color",
                value: [
                  {
                    name: "--color-dark-tint-50"
                  }
                ]
              }
            ]
          },
          {
            name: "--progress--border-left-color",
            value: [
              {
                name: "--border-left-color"
              }
            ],
            variants: [
              {
                name: "--progress--light--border-left-color",
                value: [
                  {
                    name: "--color-light-shade-50"
                  }
                ]
              },
              {
                name: "--progress--dark--border-left-color",
                value: [
                  {
                    name: "--color-dark-tint-50"
                  }
                ]
              }
            ]
          }
        ]
      },
      {
        name: "--progress--border-style",
        value: [
          {
            name: "--progress--border-top-style",
            value: [
              {
                name: "--border-top-style"
              }
            ]
          },
          {
            name: "--progress--border-right-style",
            value: [
              {
                name: "--border-right-style"
              }
            ]
          },
          {
            name: "--progress--border-bottom-style",
            value: [
              {
                name: "--border-bottom-style"
              }
            ]
          },
          {
            name: "--progress--border-left-style",
            value: [
              {
                name: "--border-left-style"
              }
            ]
          }
        ]
      },
      {
        name: "--progress--border-width",
        value: [
          {
            name: "--progress--border-top-width",
            value: [
              {
                name: "--border-top-width"
              }
            ]
          },
          {
            name: "--progress--border-right-width",
            value: [
              {
                name: "--border-right-width"
              }
            ]
          },
          {
            name: "--progress--border-bottom-width",
            value: [
              {
                name: "--border-bottom-width"
              }
            ]
          },
          {
            name: "--progress--border-left-width",
            value: [
              {
                name: "--border-left-width"
              }
            ]
          }
        ]
      },
      {
        name: "--progress--box-shadow",
        value: [
          {
            name: "--progress--box-shadow-x-offset",
            value: [
              {
                name: "--box-shadow-offset-x"
              }
            ]
          },
          {
            name: "--progress--box-shadow-y-offset",
            value: [
              {
                name: "--box-shadow-offset-y"
              }
            ]
          },
          {
            name: "--progress--box-shadow-blur-radius",
            value: [
              {
                name: "--box-shadow-blur-radius"
              }
            ]
          },
          {
            name: "--progress--box-shadow-spread-radius",
            value: [
              {
                name: "--box-shadow-spread-radius"
              }
            ]
          },
          {
            name: "--progress--box-shadow-color",
            value: [
              {
                name: "--box-shadow-color"
              }
            ]
          }
        ]
      },
      {
        name: "--progress--height",
        variants: [
          {
            name: "--progress--sm--height",
            value: [
              {
                value: "calc(0.75rem * var(--size-multiplier-sm))"
              }
            ]
          },
          {
            name: "--progress--md--height",
            value: [
              {
                value: "calc(0.75rem * var(--size-multiplier-md))"
              }
            ]
          },
          {
            name: "--progress--lg--height",
            value: [
              {
                value: "calc(0.75rem * var(--size-multiplier-lg))"
              }
            ]
          }
        ]
      }
    ]
  }
};
export default manifest;
