import type { PropType } from 'vue';
import type { Placement } from '@floating-ui/dom';
import type { ComputePositionConfig } from '@floating-ui/core';
declare const _default: import("vue").DefineComponent<{
    /**
     * The color variant of the tooltip
     * @name color
     * @type light | dark
     * @default
     */
    color: {
        type: StringConstructor;
        default: undefined;
    };
    /**
     * The disabled state of the tooltip
     * @name disabled
     * @type Boolean
     * @default false
     */
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Used to manually control the visibility of the tooltip
     * @name visible
     * @type Boolean
     * @default undefined
     */
    visible: {
        type: BooleanConstructor;
        default: undefined;
    };
    /**
     * The identifier of the tooltip
     * @name name
     * @type String
     * @default uid()
     */
    name: {
        type: StringConstructor;
        default: () => string;
    };
    /**
     * Displays an arrow on the tooltip pointing to the trigger element
     * @name arrow
     * @type Boolean
     * @default true
     */
    arrow: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The placement of the tooltip
     * @name placement
     * @type top | top-start | top-end | bottom | bottom-start | bottom-end | left | left-start | left-end | right | right-start | right-end
     * @default false
     */
    placement: {
        type: PropType<Placement>;
        default: string;
    };
    /**
     * The events used to trigger the tooltip
     * @name events
     * @type hover | focus | click | manual
     * @default [hover, focus]
     */
    events: {
        type: PropType<any>;
        default: () => string[];
    };
    /**
     * The offset of the tooltip relative to the trigger element
     * @name offset
     * @type Number
     * @default 6
     */
    offset: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Determines whether hover state should be transferred from trigger to popup
     * @name interactable
     * @type Boolean
     * @default false
     */
    interactable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Used to override the floating-ui options used for creating the tooltip
     * @name popupOptions
     * @type Object
     * @default {}
     */
    popupOptions: {
        type: PropType<Partial<ComputePositionConfig>>;
        default: () => {};
    };
    /**
     * The size variant of the tooltip
     * @name size
     * @type sm | md | lg
     * @default
     */
    size: {
        type: StringConstructor;
        default: undefined;
    };
    /**
     * Delay in milliseconds before the tooltip is hidden on hover
     * @name hoverHideDelay
     * @type Number
     * @default 300
     */
    hoverHideDelay: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Animation duration in milliseconds
     * @name animationDuration
     * @type Number
     * @default 300
     */
    animationDuration: {
        type: NumberConstructor;
        default: number;
    };
}, {
    wrapperRef: import("vue").Ref<HTMLElement | null>;
    triggerRef: import("vue").Ref<HTMLElement | null>;
    popupRef: import("vue").Ref<HTMLElement | null>;
    arrowRef: import("vue").Ref<HTMLElement | null>;
    visible: any;
    onKeyEscape: any;
    classes: import("vue").ComputedRef<{
        [x: string]: boolean;
    }>;
}, unknown, {}, {}, import("vue").ComponentOptionsMixin, import("vue").ComponentOptionsMixin, ("update:visible" | "click:outside")[], "update:visible" | "click:outside", import("vue").VNodeProps & import("vue").AllowedComponentProps & import("vue").ComponentCustomProps, Readonly<import("vue").ExtractPropTypes<{
    /**
     * The color variant of the tooltip
     * @name color
     * @type light | dark
     * @default
     */
    color: {
        type: StringConstructor;
        default: undefined;
    };
    /**
     * The disabled state of the tooltip
     * @name disabled
     * @type Boolean
     * @default false
     */
    disabled: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Used to manually control the visibility of the tooltip
     * @name visible
     * @type Boolean
     * @default undefined
     */
    visible: {
        type: BooleanConstructor;
        default: undefined;
    };
    /**
     * The identifier of the tooltip
     * @name name
     * @type String
     * @default uid()
     */
    name: {
        type: StringConstructor;
        default: () => string;
    };
    /**
     * Displays an arrow on the tooltip pointing to the trigger element
     * @name arrow
     * @type Boolean
     * @default true
     */
    arrow: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * The placement of the tooltip
     * @name placement
     * @type top | top-start | top-end | bottom | bottom-start | bottom-end | left | left-start | left-end | right | right-start | right-end
     * @default false
     */
    placement: {
        type: PropType<Placement>;
        default: string;
    };
    /**
     * The events used to trigger the tooltip
     * @name events
     * @type hover | focus | click | manual
     * @default [hover, focus]
     */
    events: {
        type: PropType<any>;
        default: () => string[];
    };
    /**
     * The offset of the tooltip relative to the trigger element
     * @name offset
     * @type Number
     * @default 6
     */
    offset: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Determines whether hover state should be transferred from trigger to popup
     * @name interactable
     * @type Boolean
     * @default false
     */
    interactable: {
        type: BooleanConstructor;
        default: boolean;
    };
    /**
     * Used to override the floating-ui options used for creating the tooltip
     * @name popupOptions
     * @type Object
     * @default {}
     */
    popupOptions: {
        type: PropType<Partial<ComputePositionConfig>>;
        default: () => {};
    };
    /**
     * The size variant of the tooltip
     * @name size
     * @type sm | md | lg
     * @default
     */
    size: {
        type: StringConstructor;
        default: undefined;
    };
    /**
     * Delay in milliseconds before the tooltip is hidden on hover
     * @name hoverHideDelay
     * @type Number
     * @default 300
     */
    hoverHideDelay: {
        type: NumberConstructor;
        default: number;
    };
    /**
     * Animation duration in milliseconds
     * @name animationDuration
     * @type Number
     * @default 300
     */
    animationDuration: {
        type: NumberConstructor;
        default: number;
    };
}>> & {
    "onUpdate:visible"?: ((...args: any[]) => any) | undefined;
    "onClick:outside"?: ((...args: any[]) => any) | undefined;
}, {
    color: string;
    size: string;
    name: string;
    placement: Placement;
    disabled: boolean;
    visible: boolean;
    events: any;
    offset: number;
    animationDuration: number;
    arrow: boolean;
    interactable: boolean;
    popupOptions: Partial<ComputePositionConfig>;
    hoverHideDelay: number;
}, {}>;
export default _default;
